@@ -1,14 +1,40 @@
+use pyo3::exceptions;
+use pyo3::prelude::*;
+use pyo3::types::*;
 use std::marker::PhantomData;
 use std::sync::{Arc, Mutex};
 
+mod iterators;
 mod normalization;
 mod pretokenization;
 mod regex;
 
+pub use iterators::*;
 pub use normalization::*;
 pub use pretokenization::*;
 pub use regex::*;
 
+// PyChar
+// This type is a temporary hack to accept `char` as argument
+// To be removed once https://github.com/PyO3/pyo3/pull/1282 has been released
+pub struct PyChar(pub char);
+
+impl FromPyObject<'_> for PyChar {
+    fn extract(obj: &PyAny) -> PyResult<Self> {
+        let s = PyString::try_from(obj)?.to_str()?;
+        let mut iter = s.chars();
+        if let (Some(ch), None) = (iter.next(), iter.next()) {
+            Ok(Self(ch))
+        } else {
+            Err(exceptions::PyValueError::new_err(
+                "expected a string of length 1",
+            ))
+        }
+    }
+}
+
+// RefMut utils
+
 pub trait DestroyPtr {
     fn destroy(&mut self);
 }
