@@ -3,10 +3,11 @@ use regex::Regex;
 use crate::tokenizer::{
     pattern::Invert, PreTokenizedString, PreTokenizer, Result, SplitDelimiterBehavior,
 };
+use crate::utils::macro_rules_attribute;
 
 #[derive(Clone, Debug, PartialEq)]
+#[macro_rules_attribute(impl_serde_type!)]
 pub struct Whitespace;
-impl_serde_unit_struct!(WhitespaceVisitor, Whitespace);
 
 impl Default for Whitespace {
     fn default() -> Self {
@@ -28,8 +29,8 @@ impl PreTokenizer for Whitespace {
 }
 
 #[derive(Copy, Clone, Debug, PartialEq)]
+#[macro_rules_attribute(impl_serde_type!)]
 pub struct WhitespaceSplit;
-impl_serde_unit_struct!(WhitespaceSplitVisitor, WhitespaceSplit);
 
 impl PreTokenizer for WhitespaceSplit {
     fn pre_tokenize(&self, pretokenized: &mut PreTokenizedString) -> Result<()> {
